@@ -1,4 +1,6 @@
 rsconnect::deployApp(
   rprojroot::find_package_root_file("inst/examples/flights"),
-  appName = "flights", account = "testing-apps"
+  appName = "flights",
+  account = "bslib",
+  forceUpdate = TRUE
 )
